﻿/**
 * Менеджер деревьев.
 * Представляет собой интерфейс для доступа ко всем деревьям
 * Позволяет по тегу дерева получить на него ссылку.
 * На текущий момент содержит в себе:
 *
 * @example
 * // Работа с деревом
 * // Доступ к менеджеру деревьев находится в переменной ps.pl.tm (провайдеры -> мастер платформа -> менеджер деревьев)
 * // доступ к конкретному дереву осуществляется по тагу дерева например ("st", "rmt", "uat")
 * // где st - дерево топологии, rmt - дерево сборщиков данных, uat - дерево в котором хранится информация о
 * // данных пользователя
 * ps.pl.tm(new v2.string("rmt")).then(function(ref){
 *     // ref - это ссылка на объект
 *     // метод value возвращает целевой объект. В данном случае дерево  {@type Trees.GlobalTree}
 *     var tree = ref.value();
 * }, function(err){
 *     // в случае неудачи придет ошибка.
 *     // обычно в ошибке содержится три переменные err - код ошибки, message - краткое описание, sub - если к этому
 *     // привела другая ошибка внутри системы.
 * })
 *
 * @group manager
 * @namespace Trees
 */
function Trees() {
    /**
     *  Вернет ссылку на дерево. В качестве идентификатора следует указать тег дерева.
     *
     * @public
     * @function get
     * @param {v2.string} treeTag Тег дерева. Например: "rmt", "uat"
     * @returns {tools.promise}
     * @memberof Trees
     */
    this.get = function (treeTag) {

    };
    /**
     * Возвращает булевое значение о существовании дерева
     *
     * @public
     * @function is_tree_exist
     * @param {v2.string} treeTag Тег дерева. Например: "rmt", "uat"
     * @returns {boolean}
     * @memberof Trees
     */
    this.is_tree_exist = function (treeTag) {

    }
}
